BaseApi class abstract

Constructors

BaseApi({required Basejson req, bool showDefaultError = true, bool skipErrorRespCheck = false, bool isHttps = false})

Properties

callContext CallContext
getter/setter pair
deserialiser → dynamic
no setter
getEndpoint String
no setter
getOutgressLog String
no setter
hashCode int
The hash code for this object.
no setterinherited
final
hostName String?
getter/setter pair
isHttps bool
getter/setter pair
port String?
getter/setter pair
req Basejson
getter/setter pair
restCall → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDefaultError bool
getter/setter pair
skipErrorRespCheck bool
getter/setter pair
uri Uri
getter/setter pair
url String?
getter/setter pair

Methods

call() Future<CallContext>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBearerToken(String token) → void
toString() String
A string representation of this object.
inherited
triggerCall() Future

Operators

operator ==(Object other) bool
The equality operator.
inherited