BasePacket class
- Implemented types
Constructors
- BasePacket({required String packetType, required String payload, String? sessionId})
-
BasePacket.fromJson(Map<
String, dynamic> json) -
factory
- BasePacket.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- packetType ↔ String
-
getter/setter pair
- payload ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited