Error class
Constructors
- Error({int? errorId, String? errorMessage, String? errorDescription})
-
Error.fromJson(Map<
String, dynamic> json) -
factory
- Error.fromRawJson(String str)
-
factory
Properties
- errorDescription → String?
-
final
- errorId → int?
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited