ErrorResp class

Constructors

ErrorResp({int? statusCode, bool? status, Error? error})
ErrorResp.fromJson(Map<String, dynamic> json)
factory
ErrorResp.fromRawJson(String str)
factory

Properties

error Error?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status bool?
final
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited