PageResp class

Constructors

PageResp({bool? first, bool? last, int? page, int? size, Sort? sort, int? totalElements, int? totalPages})

Properties

first bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
last bool?
getter/setter pair
page int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
getter/setter pair
sort Sort?
getter/setter pair
totalElements int?
getter/setter pair
totalPages int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited