SearchDetail class

Constructors

SearchDetail({bool? globalSearch, required List<SearchBy?> searchBy})
SearchDetail.fromJson(Map<String, dynamic> json)
factory
SearchDetail.fromRawJson(String str)
factory

Properties

globalSearch bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBy List<SearchBy?>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited