PageReq class
Constructors
- PageReq({PaginationDetail? paginationDetail, SearchDetail? searchDetail, String? createdBy, String? updatedBy})
Properties
- createdBy ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- paginationDetail ↔ PaginationDetail?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchDetail ↔ SearchDetail?
-
getter/setter pair
- updatedBy ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited