PaginationDetail class
Constructors
- PaginationDetail({String? order, int? page, bool? pageable, int? size, String? sort})
-
PaginationDetail.fromJson(Map<
String, dynamic> json) -
factory
- PaginationDetail.fromRawJson(String str)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- order ↔ String?
-
getter/setter pair
- page ↔ int?
-
getter/setter pair
- pageable ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ int?
-
getter/setter pair
- sort ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toRawJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited