Utils class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- curFormat → NumberFormat
-
final
Static Methods
-
cacheData(
String key, String data) → Future< void> -
downloadCSV(
String file, String fileName) → void -
formatDouble(
double? value) → String -
formatInt(
int? value) → String -
getCachedData(
String label) → Future< String?> -
getCurrentDateTimeString(
) → String -
getEndOfMonth(
DateTime dayOfMonth) → DateTime -
getExchangeName(
String? contractCode) → String -
getFormattedDate(
DateTime date, String format) → String -
getShortSymbolName(
String? contractCode) → String -
getStartOfMonth(
DateTime dayOfMonth) → DateTime -
getSymbolName(
String? contractCode) → String -
intToDecimalStr(
int? priceInLong, int factor) → String -
pickDate(
{DateTime? selectedDate, required BuildContext context}) → Future< DateTime> -
productof(
String? qty, String? price) → String -
stringToLong(
String? priceInDecimal, int factor) → int -
timestampToTime(
int? timeStamp) → String -
toDecimal(
String? priceInLong, int factor) → double -
toDecimalString(
String? priceInLong, int factor) → String